@@ -5,9 +5,11 @@ Test connection with as_dict=True.
 
 import unittest
 
+import pytest
+
 import pymssql
 
-from .helpers import config, mssql_server_required
+from .helpers import config
 
 def pymssqlconn(**kwargs):
     return pymssql.connect(
@@ -20,7 +22,7 @@ def pymssqlconn(**kwargs):
         )
 
 
-@mssql_server_required
+@pytest.mark.mssql_server_required
 class TestConnectionAsDict(unittest.TestCase):
 
     def setUp(self):
@@ -31,7 +33,7 @@ class TestConnectionAsDict(unittest.TestCase):
         cursor = self.conn.cursor()
         cursor.execute("SELECT 'foo' AS first_name, 'bar' AS last_name")
         data = cursor.fetchall()
-        self.assertEqual(data, [{'first_name': u'foo', 'last_name': u'bar'}])
+        self.assertEqual(data, [{'first_name': 'foo', 'last_name': 'bar'}])
 
     def test_no_results_with_connection_as_dict(self):
         # Make sure that checking for columns without names doesn't break
